@@ -28,6 +28,7 @@ from aea.cli.utils.click_utils import PublicIdParameter, registry_flag
 from aea.cli.utils.config import load_item_config
 from aea.cli.utils.context import Context
 from aea.cli.utils.decorators import check_aea_project, clean_after, pass_ctx
+from aea.cli.utils.loggers import logger
 from aea.cli.utils.package_utils import (
     copy_package_directory,
     find_item_in_distribution,
@@ -206,7 +207,7 @@ def fetch_item_mixed(
             ctx, item_type, item_public_id, dest_path
         )
     except click.ClickException:
-        click.echo("Fetch from local registry failed, trying remote registry...")
+        logger.debug("Fetch from local registry failed, trying remote registry...")
         # the following might raise exception, but we don't catch it this time
         package_path = fetch_package(
             item_type, public_id=item_public_id, cwd=ctx.cwd, dest=dest_path
