@@ -17,6 +17,7 @@
 #
 # ------------------------------------------------------------------------------
 """Implementation of the 'aea config' subcommand."""
+import json
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
@@ -61,7 +62,7 @@ def get(ctx: Context, json_path: str):
 @click.option(
     "--type",
     default="str",
-    type=click.Choice(["str", "int", "bool", "float"]),
+    type=click.Choice(["str", "int", "bool", "float", "dict", "list"]),
     help="Specify the type of the value.",
 )
 @click.argument("JSON_PATH", required=True)
@@ -192,8 +193,10 @@ class ConfigGetSet:
 
         if attr_name not in parent_obj:
             raise click.ClickException("Attribute '{}' not found.".format(attr_name))
-        if not isinstance(parent_obj.get(attr_name), (str, int, bool, float)):
-            raise click.ClickException(
+        if not isinstance(
+            parent_obj.get(attr_name), (str, int, bool, float, dict, list)
+        ):
+            raise click.ClickException(  # pragma: nocover
                 "Attribute '{}' is not of primitive type.".format(attr_name)
             )
         return parent_obj
@@ -314,11 +317,13 @@ class ConfigGetSet:
         """
         type_ = FROM_STRING_TO_TYPE[type_str]
         try:
-            if type_ != bool:
-                parent_object[self.attr_name] = type_(value)
-            else:
+            if type_ == bool:
                 parent_object[self.attr_name] = value not in FALSE_EQUIVALENTS
-        except ValueError:  # pragma: no cover
+            elif type_ in (dict, list):
+                parent_object[self.attr_name] = json.loads(value)
+            else:
+                parent_object[self.attr_name] = type_(value)
+        except (ValueError, json.decoder.JSONDecodeError):  # pragma: no cover
             raise click.ClickException(
                 "Cannot convert {} to type {}".format(value, type_)
             )
