@@ -102,7 +102,7 @@ def create_aea(
 
     if author is not None:
         if local:
-            do_init(author, False, False, False)
+            do_init(author, False, False, False)  # pragma: nocover
         else:
             raise click.ClickException(
                 "Author is not set up. Please use 'aea init' to initialize."
@@ -177,9 +177,9 @@ def _crete_agent_config(ctx: Context, agent_name: str, set_author: str) -> Agent
         license_=DEFAULT_LICENSE,
         registry_path=os.path.join("..", DEFAULT_REGISTRY_PATH),
         description="",
+        default_ledger=DEFAULT_LEDGER,
+        default_connection=str(DEFAULT_CONNECTION.to_any()),
     )
-    agent_config.default_connection = str(DEFAULT_CONNECTION)
-    agent_config.default_ledger = DEFAULT_LEDGER
 
     with open(os.path.join(agent_name, DEFAULT_AEA_CONFIG_FILE), "w") as config_file:
         ctx.agent_loader.dump(agent_config, config_file)
