@@ -23,7 +23,6 @@ import uuid
 from typing import Any, Dict, Optional, Tuple
 
 from aea.common import Address
-from aea.configurations.constants import DEFAULT_LEDGER
 from aea.crypto.ledger_apis import LedgerApis
 from aea.exceptions import enforce
 from aea.helpers.search.generic import (
@@ -37,14 +36,12 @@ from aea.helpers.transaction.base import Terms
 from aea.skills.base import Model
 
 
-DEFAULT_LEDGER_ID = DEFAULT_LEDGER
 DEFAULT_IS_LEDGER_TX = True
 
-DEFAULT_CURRENCY_ID = "FET"
 DEFAULT_UNIT_PRICE = 4
 DEFAULT_SERVICE_ID = "generic_service"
 
-DEFAULT_LOCATION = {"longitude": 51.5194, "latitude": 0.1270}
+DEFAULT_LOCATION = {"longitude": 0.1270, "latitude": 51.5194}
 DEFAULT_SERVICE_DATA = {"key": "seller_service", "value": "generic_service"}
 
 DEFAULT_HAS_DATA_SOURCE = False
@@ -65,10 +62,10 @@ class GenericStrategy(Model):
 
         :return: None
         """
-        self._ledger_id = kwargs.pop("ledger_id", DEFAULT_LEDGER_ID)
+        ledger_id = kwargs.pop("ledger_id", None)
+        currency_id = kwargs.pop("currency_id", None)
         self._is_ledger_tx = kwargs.pop("is_ledger_tx", DEFAULT_IS_LEDGER_TX)
 
-        self._currency_id = kwargs.pop("currency_id", DEFAULT_CURRENCY_ID)
         self._unit_price = kwargs.pop("unit_price", DEFAULT_UNIT_PRICE)
         self._service_id = kwargs.pop("service_id", DEFAULT_SERVICE_ID)
 
@@ -97,16 +94,28 @@ class GenericStrategy(Model):
         }
 
         super().__init__(**kwargs)
+        self._ledger_id = (
+            ledger_id if ledger_id is not None else self.context.default_ledger_id
+        )
+        if currency_id is None:
+            currency_id = self.context.currency_denominations.get(self._ledger_id, None)
+            enforce(
+                currency_id is not None,
+                f"Currency denomination for ledger_id={self._ledger_id} not specified.",
+            )
+        self._currency_id = currency_id
         enforce(
             self.context.agent_addresses.get(self._ledger_id, None) is not None,
             "Wallet does not contain cryptos for provided ledger id.",
         )
+        self._data_for_sale = data_for_sale
 
+    @property
+    def data_for_sale(self) -> Dict[str, str]:
+        """Get the data for sale."""
         if self._has_data_source:
-            self._data_for_sale = self.collect_from_data_source()  # pragma: nocover
-        else:
-            self._data_for_sale = data_for_sale
-        self._sale_quantity = len(data_for_sale)
+            return self.collect_from_data_source()  # pragma: nocover
+        return self._data_for_sale
 
     @property
     def ledger_id(self) -> str:
@@ -181,8 +190,10 @@ class GenericStrategy(Model):
         :param counterparty_address: the counterparty of the proposal.
         :return: a tuple of proposal, terms and the weather data
         """
+        data_for_sale = self.data_for_sale
+        sale_quantity = len(data_for_sale)
         seller_address = self.context.agent_addresses[self.ledger_id]
-        total_price = self._sale_quantity * self._unit_price
+        total_price = sale_quantity * self._unit_price
         if self.is_ledger_tx:
             tx_nonce = LedgerApis.generate_tx_nonce(
                 identifier=self.ledger_id,
@@ -197,7 +208,7 @@ class GenericStrategy(Model):
                 "price": total_price,
                 "currency_id": self._currency_id,
                 "service_id": self._service_id,
-                "quantity": self._sale_quantity,
+                "quantity": sale_quantity,
                 "tx_nonce": tx_nonce,
             }
         )
@@ -206,12 +217,12 @@ class GenericStrategy(Model):
             sender_address=seller_address,
             counterparty_address=counterparty_address,
             amount_by_currency_id={self._currency_id: total_price},
-            quantities_by_good_id={self._service_id: -self._sale_quantity},
+            quantities_by_good_id={self._service_id: -sale_quantity},
             is_sender_payable_tx_fee=False,
             nonce=tx_nonce,
             fee_by_currency_id={self._currency_id: 0},
         )
-        return proposal, terms, self._data_for_sale
+        return proposal, terms, data_for_sale
 
     def collect_from_data_source(self) -> Dict[str, str]:
         """Implement the logic to communicate with the sensor."""
