@@ -26,6 +26,9 @@ from aea.crypto.ledger_apis import LedgerApis
 from aea.protocols.base import Message
 from aea.skills.base import Handler
 
+from packages.fetchai.connections.ledger.base import (
+    CONNECTION_ID as LEDGER_CONNECTION_PUBLIC_ID,
+)
 from packages.fetchai.protocols.signing.message import SigningMessage
 from packages.fetchai.skills.tac_control.handlers import (
     OefSearchHandler as BaseOefSearchHandler,
@@ -45,7 +48,7 @@ from packages.fetchai.skills.tac_control_contract.game import Game, Phase
 from packages.fetchai.skills.tac_control_contract.parameters import Parameters
 
 
-LEDGER_API_ADDRESS = "fetchai/ledger:0.8.0"
+LEDGER_API_ADDRESS = str(LEDGER_CONNECTION_PUBLIC_ID)
 
 
 TacHandler = BaseTacHandler
@@ -155,7 +158,7 @@ class ContractApiHandler(Handler):
         :param contract_api_dialogue: the ledger api dialogue
         """
         self.context.logger.info(
-            "received ledger_api error message={} in dialogue={}.".format(
+            "received contract_api error message={} in dialogue={}.".format(
                 contract_api_msg, contract_api_dialogue
             )
         )
