@@ -48,7 +48,7 @@ MODULES_TO_PATH = {
     "aea.configurations.project": "api/configurations/project.md",
     "aea.configurations.pypi": "api/configurations/pypi.md",
     "aea.connections.base": "api/connections/base.md",
-    "aea.connections.stub.connection": "api/connections/stub/connection.md",
+    "packages.fetchai.connections.stub.connection": "api/connections/stub/connection.md",
     "aea.context.base": "api/context/base.md",
     "aea.contracts.base": "api/contracts/base.md",
     "aea.crypto.base": "api/crypto/base.md",
@@ -86,24 +86,24 @@ MODULES_TO_PATH = {
     "aea.protocols.generator.common": "api/protocols/generator/common.md",
     "aea.protocols.generator.extract_specification": "api/protocols/generator/extract_specification.md",
     "aea.protocols.generator.validate": "api/protocols/generator/validate.md",
-    "aea.protocols.default.custom_types": "api/protocols/default/custom_types.md",
-    "aea.protocols.default.dialogues": "api/protocols/default/dialogues.md",
-    "aea.protocols.default.message": "api/protocols/default/message.md",
-    "aea.protocols.default.serialization": "api/protocols/default/serialization.md",
-    "aea.protocols.signing.custom_types": "api/protocols/signing/custom_types.md",
-    "aea.protocols.signing.dialogues": "api/protocols/signing/dialogues.md",
-    "aea.protocols.signing.message": "api/protocols/signing/message.md",
-    "aea.protocols.signing.serialization": "api/protocols/signing/serialization.md",
-    "aea.protocols.state_update.dialogues": "api/protocols/state_update/dialogues.md",
-    "aea.protocols.state_update.message": "api/protocols/state_update/message.md",
-    "aea.protocols.state_update.serialization": "api/protocols/state_update/serialization.md",
+    "packages.fetchai.protocols.default.custom_types": "api/protocols/default/custom_types.md",
+    "packages.fetchai.protocols.default.dialogues": "api/protocols/default/dialogues.md",
+    "packages.fetchai.protocols.default.message": "api/protocols/default/message.md",
+    "packages.fetchai.protocols.default.serialization": "api/protocols/default/serialization.md",
+    "packages.fetchai.protocols.signing.custom_types": "api/protocols/signing/custom_types.md",
+    "packages.fetchai.protocols.signing.dialogues": "api/protocols/signing/dialogues.md",
+    "packages.fetchai.protocols.signing.message": "api/protocols/signing/message.md",
+    "packages.fetchai.protocols.signing.serialization": "api/protocols/signing/serialization.md",
+    "packages.fetchai.protocols.state_update.dialogues": "api/protocols/state_update/dialogues.md",
+    "packages.fetchai.protocols.state_update.message": "api/protocols/state_update/message.md",
+    "packages.fetchai.protocols.state_update.serialization": "api/protocols/state_update/serialization.md",
     "aea.registries.base": "api/registries/base.md",
     "aea.registries.filter": "api/registries/filter.md",
     "aea.registries.resources": "api/registries/resources.md",
     "aea.skills.base": "api/skills/base.md",
     "aea.skills.behaviours": "api/skills/behaviours.md",
     "aea.skills.tasks": "api/skills/tasks.md",
-    "aea.skills.error.handlers": "api/skills/error/handlers.md",
+    "packages.fetchai.skills.error.handlers": "api/skills/error/handlers.md",
     "aea.test_tools.generic": "api/test_tools/generic.md",
     "aea.test_tools.test_cases": "api/test_tools/test_cases.md",
     "aea.test_tools.test_skill": "api/test_tools/test_skill.md",
