@@ -62,6 +62,7 @@ unknown  # unused variable (aea/cli_gui/__main__.py:41)
 STOPPING  # unused variable (aea/cli_gui/utils.py:35)
 _call_subprocess  # unused function (aea/cli_gui/utils.py:44)
 _.latest  # unused property (aea/configurations/base.py:384)
+_.to_any  # unused property (aea/configurations/base.py:442)
 _.to_latest  # unused property (aea/configurations/base.py:442)
 _.to_uri_path  # unused property (aea/configurations/base.py:445)
 _.to_uri_path  # unused property (aea/configurations/base.py:605)
@@ -199,6 +200,8 @@ create_with_message  # unused method (aea/helpers/dialogue/base.py:1054)
 _.is_disconnecting  # unused property (aea/multiplexer.py:67)
 _.get_quantity_in_outbox  # unused method (aea/test_tools/test_skills.py:52)
 _.get_message_from_outbox  # unused method (aea/test_tools/test_skills.py:56)
+_.drop_messages_from_outbox  # unused method (aea/test_tools/test_skills.py:70)
+_.drop_messages_from_decision_maker_inbox  # unused method (aea/test_tools/test_skills.py:86)
 _.get_quantity_in_decision_maker_inbox  # unused method (aea/test_tools/test_skills.py:69)
 _.get_message_from_decision_maker_inbox  # unused method (aea/test_tools/test_skills.py:73)
 _.assert_quantity_in_outbox  # unused method (aea/test_tools/test_skills.py:79)
@@ -221,3 +224,5 @@ _.get_agent_alias  # unused method (aea/manager.py:486)
 _.DEFAULT_PYPI_INDEX_URL  # unused variable (aea/configurations/base.py:85)
 AEARunner  # unused class (aea/runner.py:84)
 _.join_thread  # unused method (aea/helpers/multiple_executor.py:430)
+_.valid_performatives  # unused property (aea/protocols/base.py:90)
+_.has_dialogue_info  # unused property (aea/protocols/base.py:244)
