@@ -34,13 +34,18 @@ from aea.aea_builder import AEABuilder
 from aea.configurations.base import SkillConfig
 from aea.configurations.constants import DEFAULT_LEDGER, DEFAULT_PRIVATE_KEY_FILE
 from aea.crypto.wallet import Wallet
-from aea.exceptions import AEAException
+from aea.exceptions import (
+    AEAActException,
+    AEAException,
+    AEAHandleException,
+    _StopRuntime,
+)
 from aea.helpers.exception_policy import ExceptionPolicyEnum
 from aea.identity.base import Identity
 from aea.mail.base import Envelope
 from aea.protocols.base import Protocol
 from aea.registries.resources import Resources
-from aea.runtime import RuntimeStates, _StopRuntime
+from aea.runtime import RuntimeStates
 from aea.skills.base import Skill, SkillContext
 
 from packages.fetchai.connections.local.connection import LocalNode, OEFLocalConnection
@@ -699,8 +704,9 @@ class TestAeaExceptionPolicy:
         self.handler.handle = self.raise_exception  # type: ignore # cause error: Cannot assign to a method
         self.aea_tool.put_inbox(self.aea_tool.dummy_envelope())
 
-        with pytest.raises(ExpectedExcepton):
-            self.aea.start()
+        with pytest.raises(AEAHandleException):
+            with pytest.raises(ExpectedExcepton):
+                self.aea.start()
 
         assert not self.aea.is_running
 
@@ -736,8 +742,9 @@ class TestAeaExceptionPolicy:
         self.aea._skills_exception_policy = ExceptionPolicyEnum.propagate
         self.behaviour.act = self.raise_exception  # type: ignore # cause error: Cannot assign to a method
 
-        with pytest.raises(ExpectedExcepton):
-            self.aea.start()
+        with pytest.raises(AEAActException):
+            with pytest.raises(ExpectedExcepton):
+                self.aea.start()
 
         assert self.aea.runtime.state == RuntimeStates.error
 
