@@ -25,7 +25,7 @@ import sys
 from typing import cast
 
 from aea.aea import AEA
-from aea.configurations.base import ConnectionConfig, PublicId
+from aea.configurations.base import ConnectionConfig
 from aea.crypto.fetchai import FetchAICrypto
 from aea.crypto.helpers import PRIVATE_KEY_PATH_SCHEMA, create_private_key
 from aea.crypto.wallet import Wallet
@@ -37,6 +37,8 @@ from aea.skills.base import Skill
 from packages.fetchai.connections.ledger.connection import LedgerConnection
 from packages.fetchai.connections.p2p_libp2p.connection import P2PLibp2pConnection
 from packages.fetchai.connections.soef.connection import SOEFConnection
+from packages.fetchai.protocols.ledger_api.message import LedgerApiMessage
+from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 from packages.fetchai.skills.weather_client.strategy import Strategy
 
 
@@ -77,8 +79,8 @@ def run():
 
     # specify the default routing for some protocols
     default_routing = {
-        PublicId.from_str("fetchai/ledger_api:0.6.0"): LedgerConnection.connection_id,
-        PublicId.from_str("fetchai/oef_search:0.9.0"): SOEFConnection.connection_id,
+        LedgerApiMessage.protocol_id: LedgerConnection.connection_id,
+        OefSearchMessage.protocol_id: SOEFConnection.connection_id,
     }
     default_connection = P2PLibp2pConnection.connection_id
 
@@ -149,7 +151,7 @@ def run():
         api_key=API_KEY,
         soef_addr=SOEF_ADDR,
         soef_port=SOEF_PORT,
-        restricted_to_protocols={PublicId.from_str("fetchai/oef_search:0.9.0")},
+        restricted_to_protocols={OefSearchMessage.protocol_id},
         connection_id=SOEFConnection.connection_id,
     )
     soef_connection = SOEFConnection(configuration=configuration, identity=identity)
