@@ -40,7 +40,7 @@ from packages.fetchai.protocols.contract_api.dialogues import (
 )
 from packages.fetchai.protocols.contract_api.message import ContractApiMessage
 from packages.fetchai.protocols.contract_api.message import (
-    logger as contract_api_message_logger,
+    _default_logger as contract_api_message_logger,
 )
 
 from tests.conftest import ROOT_DIR
