@@ -35,7 +35,7 @@ from aea.protocols.dialogue.base import DialogueLabel
 import packages
 from packages.fetchai.protocols.tac.dialogues import TacDialogue, TacDialogues
 from packages.fetchai.protocols.tac.message import TacMessage
-from packages.fetchai.protocols.tac.message import logger as tac_message_logger
+from packages.fetchai.protocols.tac.message import _default_logger as tac_message_logger
 
 from tests.conftest import ROOT_DIR
 
